travis
======

Your package test wonderfully using the :doc:`../tox/main` tool. Now maybe the right time
to automate the process using Travis-CI_.

This option will add the relevant files to expose your package to Travis-CI_.
You still need to perform by hand the activation of your package on Travis-CI_.
Have a look at :doc:`travis_tutorial` for a step by step guide on how to do that.

Modifications
-------------

.. raw:: html
    :file: modifications.html


.. _Travis-CI: http://travis-ci.com/
